abacusai.modification_lock_info — AbacusAI documentation

# `abacusai.modification_lock_info`

## Module Contents

### Classes

`ModificationLockInfo` | Information about a modification lock for a certain object

class abacusai.modification_lock_info.ModificationLockInfo(client, modificationLock=None, userEmails=None, organizationGroups=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Information about a modification lock for a certain object

  Parameters

    - client (ApiClient) – An authenticated API Client instance

    - modificationLock (bool) – Whether or not the object has its modification lock activated.

    - userEmails (list of strings) – The list of user emails allowed to modify the object if the object’s modification lock is activated.

    - organizationGroups (list of unique string identifiers) – The list organization groups allowed to modify the object if the object’s modification lock is activated.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns

      The dict value representation of the class parameters

    Return type

      dict